<?php

namespace Wp618\Optimize;

if ( !defined( 'ABSPATH' ) ) exit;

//
class Action{
    private $app;

    //
    public function __construct(){
        $this->app = App::getInstance();

        $this->execute();
    }

    //
    private function execute(){
        $config = get_app_config();

        // xml-rpc
        if(!empty($config['general']['is_close_xml_rpc'])) {
            add_filter('xmlrpc_enabled', '__return_false');
        }
        // emoji
        if(!empty($config['general']['is_close_emoji'])) {
            add_action( 'init', [$this, 'disable_emojis']);
        }
        // welcome
        if(!empty($config['backend']['is_close_dashboard_welcome'])) {
            add_action('admin_init', function () {
                remove_action('welcome_panel', 'wp_welcome_panel');
            });
        }
        // news
        if(!empty($config['backend']['is_close_dashboard_news'])) {
            add_action('wp_dashboard_setup', function () {
                global $wp_meta_boxes;
                unset($wp_meta_boxes['dashboard']['side']['core']['dashboard_primary']);
            });
        }
        // remove generator
        if(!empty($config['general']['is_remove_generator'])) {
            remove_action('wp_head', 'wp_generator');
        }
    }

    //
    public function disable_emojis(){
        // 禁用 Emoji 插件的前端脚本
        remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
        remove_action( 'wp_print_styles', 'print_emoji_styles' );
        remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
        remove_action( 'admin_print_styles', 'print_emoji_styles' );
        remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
        remove_filter( 'comment_text_rss', 'wp_staticize_emoji' );
        remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );

        // 禁用 Emoji 插件的 TinyMCE 插件
        add_filter( 'tiny_mce_plugins', [$this, 'disable_emojicons_tinymce'] );
        // 禁用 Emoji 插件的 DNS 预取
        add_filter( 'emoji_svg_url', '__return_false' );
    }

    //
    public function disable_emojicons_tinymce( $plugins ) {
        if ( is_array( $plugins ) ) {
            return array_diff( $plugins, array( 'wpemoji' ) );
        } else {
            return array();
        }
    }
}
